@@ -1,8 +1,10 @@
-from django.urls import re_path, reverse_lazy
+from django.urls import re_path
+from django.urls import reverse_lazy
 from django.utils.translation import gettext as _
 from wiki.core.plugins import registry
 from wiki.core.plugins.base import BasePlugin
-from wiki.plugins.links import settings, views
+from wiki.plugins.links import settings
+from wiki.plugins.links import views
 from wiki.plugins.links.mdx.djangowikilinks import WikiPathExtension
 from wiki.plugins.links.mdx.urlize import makeExtension as urlize_makeExtension
 
